# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import winrt.system
from winrt._winrt_windows_applicationmodel_contacts_dataprovider import (
    ContactDataProviderConnection,
    ContactDataProviderTriggerDetails,
    ContactListCreateOrUpdateContactRequest,
    ContactListCreateOrUpdateContactRequestEventArgs,
    ContactListDeleteContactRequest,
    ContactListDeleteContactRequestEventArgs,
    ContactListServerSearchReadBatchRequest,
    ContactListServerSearchReadBatchRequestEventArgs,
    ContactListSyncManagerSyncRequest,
    ContactListSyncManagerSyncRequestEventArgs,
)

__all__ = [
    "ContactDataProviderConnection",
    "ContactDataProviderTriggerDetails",
    "ContactListCreateOrUpdateContactRequest",
    "ContactListCreateOrUpdateContactRequestEventArgs",
    "ContactListDeleteContactRequest",
    "ContactListDeleteContactRequestEventArgs",
    "ContactListServerSearchReadBatchRequest",
    "ContactListServerSearchReadBatchRequestEventArgs",
    "ContactListSyncManagerSyncRequest",
    "ContactListSyncManagerSyncRequestEventArgs",
]

